@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Calculate date-time operations
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0303';
 
 use strict;
 use warnings;
@@ -124,12 +124,19 @@ Bot::BasicBot::Pluggable::Module::DateTimeCalc - Calculate date-time operations
 
 =head1 VERSION
 
-version 0.0302
+version 0.0303
 
 =head1 SYNOPSIS
 
   use Bot::BasicBot::Pluggable::Module::DateTimeCalc;
-  my $bot = Bot::BasicBot::Pluggable::Module::DateTimeCalc->new( nick => 'TimeBot', '...' );
+  my $bot = Bot::BasicBot::Pluggable::Module::DateTimeCalc->new(
+    server      => 'irc.somewhere.org',
+    port        => '6667',
+    channels    => ['#bots'],
+    nick        => 'TimeBot',
+    name        => 'Your Name Bot',
+    ignore_list => [qw/other_bot some_fool/],
+  );
   $bot->run();
 
 =head1 DESCRIPTION
